from rest_framework.serializers import ModelSerializer


def generate_sub_serializer(class_model,
                            model_fields):
    """
    Return a serializer of the class

    :param class_model: Model
    :param model_fields: fields in class
    :return serializer:
    """
    class SubModelSerializer(ModelSerializer):
        def __init__(self, *args, **kwargs):
            request = kwargs.get('context', {}).get('request')
            str_fields = request.GET.get('info', '') if request else None
            fields = str_fields.split(',') if str_fields else None
            super(SubModelSerializer, self).__init__(*args, **kwargs)

            if fields is not None:
                allowed = set(fields)
                existing = set(fields)
                for field_name in existing - allowed:
                    fields.pop(field_name)

        class Meta:
            model = class_model
            fields = model_fields

    return SubModelSerializer



import setuptools

setuptools.setup(
    name="django_elastic_filter",
    version="1.0.16",
    author="Saeed Hassani Borzadaran",
    author_email="hassanisaeed19@gmail.com",
    description="Django Elastic Filter for Models",
    long_description_content_type="text/markdown",
    url="https://github.com/realsaeedhassani/django-elastic-filter",
    project_urls={
        "Bug Tracker": "https://github.com/realsaeedhassani/django-elastic-filter/issues/new",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)


from pydoc import locate


def get_all_fields(fields: list, rest: dict) -> list:
    for key in rest:
        fields.append(key)
    return fields


def str_to_class(path: str):
    """
    if your class name is MyClass and located in my_app.models.MyClass then:

    Example:
        path = "my_app.models.MyClass"
        my_class = to_class(path)

    :param path: String path of the module's class
    :return my_class: Object or None
    """
    try:
        my_class = locate(path)
    except ImportError:
        raise ValueError('>> Module does not exist')
    return my_class or None
